@@ -1,4 +1,6 @@
 package Net::Whois::Raw;
+$Net::Whois::Raw::VERSION = '2.87';
+# ABSTRACT: Get Whois information of domains and IP addresses.
 
 require 5.008_001;
 use Net::Whois::Raw::Common ();
@@ -8,14 +10,12 @@ use warnings;
 use strict;
 
 use Carp;
-use IO::Socket;
+use IO::Socket::IP;
 use Encode;
 use utf8;
 
 our @EXPORT = qw( whois get_whois );
 
-our $VERSION = '2.86';
-
 our ($OMIT_MSG, $CHECK_FAIL, $CHECK_EXCEED, $CACHE_DIR, $TIMEOUT, $DEBUG) = (0) x 7;
 
 our $CACHE_TIME = 60;
@@ -252,12 +252,16 @@ sub whois_query {
     my $server4query = Net::Whois::Raw::Common::get_server($dom);
     $server4query = lc $server4query;
 
+    if ( Net::Whois::Raw::Common::is_ip6addr( $srv ) ) {
+        $srv = "[$srv]";
+    }
+
     my $srv_and_port = $srv =~ /\:\d+$/ ? $srv : "$srv:43";
-    if ($class->can ('whois_query_sockparams')) {
+    if ($class->can('whois_query_sockparams')) {
         @sockparams = $class->whois_query_sockparams ($dom, $srv);
     }
     # hook for outside defined socket
-    elsif ($class->can ('whois_query_socket')) {
+    elsif ($class->can('whois_query_socket')) {
         $sock = $class->whois_query_socket ($dom, $srv);
     }
     elsif (my $ips_arrayref = get_ips_for_query($server4query)) {
@@ -294,8 +298,9 @@ sub whois_query {
 
             $prev_alarm = alarm $TIMEOUT if $TIMEOUT;
 
-            unless($sock){
-                $sock = IO::Socket::INET->new(@sockparams) || die "$srv: $!: ".join(', ', @sockparams);
+            unless ( $sock ) {
+                $sock = IO::Socket::IP->new( @sockparams )
+                    or die "$srv: $!: " . join( ', ', @sockparams );
             }
 
             if ($class->can ('whois_socket_fixup')) {
@@ -454,11 +459,20 @@ sub get_ips_for_query {
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Net::Whois::Raw -- Get Whois information for domains
+Net::Whois::Raw - Get Whois information of domains and IP addresses.
+
+=head1 VERSION
+
+version 2.87
 
 =head1 SYNOPSIS
 
@@ -533,6 +547,10 @@ the search failed and return undef in such a case.
 B<IMPORTANT>: these checks merely use pattern matching; they will work
 on several servers but certainly not on all of them.
 
+=head1 NAME
+
+Net::Whois::Raw — Get Whois information of domains and IP addresses.
+
 =head1 FUNCTIONS
 
 =over 3
@@ -623,7 +641,6 @@ You can set your own LWP::UserAgent like this:
         return LWP::UserAgent->new();
     };
 
-
 =item set_ips_for_server('whois.ripn.net', ['127.0.0.1']);
 
 You can specify IPs list which will be used for queries to desired whois server.
@@ -687,4 +704,15 @@ module) is forbidden by the registrars.
 
 L<pwhois>, L<whois>.
 
+=head1 AUTHOR
+
+Alexander Nalobin <alexander@nalobin.ru>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2002-2015 by Alexander Nalobin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
