@@ -1,4 +1,6 @@
 package Net::Whois::Raw::Common;
+$Net::Whois::Raw::Common::VERSION = '2.87';
+# ABSTRACT: Helper for Net::Whois::Raw.
 
 use Encode;
 use warnings;
@@ -604,3 +606,30 @@ sub untaint (\$) {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Whois::Raw::Common - Helper for Net::Whois::Raw.
+
+=head1 VERSION
+
+version 2.87
+
+=head1 AUTHOR
+
+Alexander Nalobin <alexander@nalobin.ru>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2002-2015 by Alexander Nalobin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
