@@ -1,8 +1,8 @@
 package Net::Whois::Raw::Data;
+$Net::Whois::Raw::Data::VERSION = '2.87';
+# ABSTRACT: Config for Net::Whois::Raw.
 
-# Use string as is
-no utf8;
-
+use utf8;
 use warnings;
 use strict;
 
@@ -1590,11 +1590,11 @@ our %strip = (
     ],
     'whois.nic.cl' => [
         '^ACE\:',
-        '^ltima modificacin',
+        '^Ъltima modificaciуn',
         '\(Database last updated on\)',
-        '^Ms informacin',
+        '^Mбs informaciуn',
         'www\.nic\.cl\/cgi-bin',
-        '^Este mensajes est impreso',
+        '^Este mensajes estб impreso',
         '^\(This message is printed',
         '^\s+\(\)$',
     ],
@@ -1735,8 +1735,8 @@ our %strip = (
         '^abide by the rules',
         '^http\:',
         'A szolgaltatas csak a',
-        '^elrhet felttelek',
-        '^hasznlhat leglisan',
+        '^elйrhetх feltйtelek',
+        '^hasznбlhatу legбlisan',
     ],
     'whois.domainregistry.ie' => [
         '^%',
@@ -1777,7 +1777,7 @@ our %strip = (
         '^remarks\:',
     ],
     'whois.nic.or.kr' => [
-        '^Ӽ ̸ .kr ƴ ',
+        '^іЧАУј­№ц АМё§АМ .krАМ ѕЖґС °жїмґ',
     ],
     'whois.nic.kz' => [
         '^Whois Server for the KZ',
@@ -2546,3 +2546,30 @@ our %query_prefix = (
 );
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Whois::Raw::Data - Config for Net::Whois::Raw.
+
+=head1 VERSION
+
+version 2.87
+
+=head1 AUTHOR
+
+Alexander Nalobin <alexander@nalobin.ru>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2002-2015 by Alexander Nalobin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
